@@ -6,19 +6,33 @@ Author: Nikolay Lysenko
 
 
 from . import (
-    filter, filter_sweep, overdrive, registry, reverb, tremolo, vibrato
+    automation,
+    equalizer,
+    filter,
+    filter_sweep,
+    overdrive,
+    registry,
+    reverb,
+    stereo,
+    tremolo,
+    vibrato,
+    volume,
 )
 from .registry import EFFECT_FN_TYPE, get_effects_registry
 
 
 __all__ = [
     'EFFECT_FN_TYPE',
+    'automation',
+    'equalizer',
     'filter',
     'filter_sweep',
     'get_effects_registry',
     'overdrive',
     'registry',
     'reverb',
+    'stereo',
     'tremolo',
-    'vibrato'
+    'vibrato',
+    'volume',
 ]
